@@ -4,7 +4,8 @@ use warnings;
 
 package CPAN::Common::Index;
 # ABSTRACT: Common library for searching CPAN modules, authors and distributions
-our $VERSION = '0.005'; # VERSION
+
+our $VERSION = '0.006';
 
 use Carp ();
 
@@ -47,7 +48,7 @@ use Class::Tiny;
 #pod       uri     => "cpan:///distfile/ETHER/Moose-2.0802.tar.gz"
 #pod     }
 #pod
-#pod The C<uri> field should a valid URI.  It may be a L<URI::cpan> or any other
+#pod The C<uri> field should be a valid URI.  It may be a L<URI::cpan> or any other
 #pod URI.  (It is up to a client to do something useful with any given URI scheme.)
 #pod
 #pod =method search_authors (ABSTRACT)
@@ -151,7 +152,7 @@ CPAN::Common::Index - Common library for searching CPAN modules, authors and dis
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 SYNOPSIS
 
@@ -232,7 +233,7 @@ The result must be formed as follows:
       uri     => "cpan:///distfile/ETHER/Moose-2.0802.tar.gz"
     }
 
-The C<uri> field should a valid URI.  It may be a L<URI::cpan> or any other
+The C<uri> field should be a valid URI.  It may be a L<URI::cpan> or any other
 URI.  (It is up to a client to do something useful with any given URI scheme.)
 
 =head2 search_authors (ABSTRACT)
@@ -335,12 +336,16 @@ David Golden <dagolden@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Kenichi Ishigaki Tatsuhiko Miyagawa
+=for stopwords Helmut Wollmersdorfer Kenichi Ishigaki Tatsuhiko Miyagawa
 
 =over 4
 
 =item *
 
+Helmut Wollmersdorfer <helmut@wollmersdorfer.at>
+
+=item *
+
 Kenichi Ishigaki <ishigaki@cpan.org>
 
 =item *
